pub struct VerificationSession { /* private fields */ }Expand description
End-to-end verification session configuration for a bundle.
Implementations
Sourceimpl VerificationSession
impl VerificationSession
pub fn new( bundle: ObligationBundle, layout: ArtifactLayout, lean_module_name: impl Into<String>, ) -> Self
pub fn with_smt_config(self, smt: SmtConfig) -> Self
pub fn with_lean_config(self, lean: LeanConfig) -> Self
pub fn with_report_stem(self, report_stem: impl Into<String>) -> Self
pub fn bundle(&self) -> &ObligationBundle
pub fn layout(&self) -> &ArtifactLayout
pub fn lean_module_name(&self) -> &str
pub fn report_stem(&self) -> &str
Sourcepub fn dry_run_report(&self) -> VerificationReport
pub fn dry_run_report(&self) -> VerificationReport
Build dry-run artifacts and return the attached verification report.
Sourcepub fn verify_report(
&self,
runner: &impl VerifierRunner,
) -> Result<VerificationReport>
pub fn verify_report( &self, runner: &impl VerifierRunner, ) -> Result<VerificationReport>
Build artifacts, execute plans, and return the resulting verification report.
Sourcepub fn verify_local_report(&self) -> Result<VerificationReport>
pub fn verify_local_report(&self) -> Result<VerificationReport>
Build artifacts, execute plans locally, and return the resulting verification report.
Sourcepub fn verify_with_ci_outputs(
&self,
runner: &impl VerifierRunner,
) -> Result<VerificationOutput>
pub fn verify_with_ci_outputs( &self, runner: &impl VerifierRunner, ) -> Result<VerificationOutput>
Build artifacts, execute plans, and write JSON / Markdown summaries beside them.
Sourcepub fn verify_local_with_ci_outputs(&self) -> Result<VerificationOutput>
pub fn verify_local_with_ci_outputs(&self) -> Result<VerificationOutput>
Build artifacts, execute plans locally, and write CI-oriented summaries.
Sourcepub fn verify_with_dry_runner(&self) -> Result<VerificationReport>
pub fn verify_with_dry_runner(&self) -> Result<VerificationReport>
Build artifacts via the real writer, then execute a dry-run runner.